@@ -40,7 +40,7 @@ static void       gail_canvas_item_get_extents              (AtkComponent      *
 					                     gint              *width,
 					                     gint              *height,
 					                     AtkCoordType      coord_type);
-
+static gint       gail_canvas_item_get_mdi_zorder           (AtkComponent      *component);
 static gboolean   gail_canvas_item_grab_focus               (AtkComponent      *component);
 static void       gail_canvas_item_remove_focus_handler     (AtkComponent      *component,
 					                     guint             handler_id);
@@ -231,7 +231,7 @@ gail_canvas_item_component_interface_init (AtkComponentIface *iface)
 
   iface->add_focus_handler = gail_canvas_item_add_focus_handler;
   iface->get_extents = gail_canvas_item_get_extents;
-  iface->get_mdi_zorder = gail_canvas_item_get_index_in_parent;
+  iface->get_mdi_zorder = gail_canvas_item_get_mdi_zorder;
   iface->grab_focus = gail_canvas_item_grab_focus;
   iface->remove_focus_handler = gail_canvas_item_remove_focus_handler;
 }
@@ -315,6 +315,14 @@ gail_canvas_item_get_extents (AtkComponent *component,
   return;
 }
 
+static gint
+gail_canvas_item_get_mdi_zorder (AtkComponent *component)
+{
+  g_return_val_if_fail (ATK_OBJECT (component), -1); 
+
+  return gail_canvas_item_get_index_in_parent (ATK_OBJECT (component));
+}
+
 static gboolean
 gail_canvas_item_grab_focus (AtkComponent    *component)
 {
