@@ -29,7 +29,7 @@ static AtkObject*            gail_item_ref_child       (AtkObject     *obj,
                                                         gint          i);
 static void                  gail_item_real_initialize (AtkObject     *obj,
                                                         gpointer      data);
-static gint                  gail_item_label_map_gtk   (GtkWidget     *widget,
+static void                  gail_item_label_map_gtk   (GtkWidget     *widget,
                                                         gpointer      data);
 static void                  gail_item_finalize        (GObject       *object);
 static void                  gail_item_init_textutil   (GailItem      *item,
@@ -177,18 +177,20 @@ gail_item_real_initialize (AtkObject *obj,
 
   label = get_label_from_item (GTK_WIDGET (data));
   if (GTK_IS_LABEL (label))
-    if (GTK_WIDGET_MAPPED (label))
-      gail_item_init_textutil (item, label);
-    else
-      g_signal_connect (label,
-                        "map",
-                        G_CALLBACK (gail_item_label_map_gtk),
-                        item);
+    {
+      if (GTK_WIDGET_MAPPED (label))
+        gail_item_init_textutil (item, label);
+      else
+        g_signal_connect (label,
+                          "map",
+                          G_CALLBACK (gail_item_label_map_gtk),
+                          item);
+    }
 
   obj->role = ATK_ROLE_LIST_ITEM;
 }
 
-static gint
+static void
 gail_item_label_map_gtk (GtkWidget *widget,
                          gpointer data)
 {
@@ -231,10 +233,13 @@ gail_item_finalize (GObject *object)
 static G_CONST_RETURN gchar*
 gail_item_get_name (AtkObject *obj)
 {
+  G_CONST_RETURN gchar* name;
+
   g_return_val_if_fail (GAIL_IS_ITEM (obj), NULL);
 
-  if (ATK_OBJECT(obj)->name != NULL)
-    return ATK_OBJECT(obj)->name;
+  name = ATK_OBJECT_CLASS (parent_class)->get_name (obj);
+  if (name != NULL)
+    return name;
   else
     {
       /*
