@@ -314,12 +314,37 @@ gail_menu_item_do_action (AtkAction *action,
     return FALSE;
 }
 
+static void
+ensure_menus_unposted (GailMenuItem *menu_item)
+{
+  AtkObject *parent;
+  GtkWidget *widget;
+
+  parent = atk_object_get_parent (ATK_OBJECT (menu_item));
+  while (parent)
+    {
+      if (GTK_IS_ACCESSIBLE (parent))
+        {
+          widget = GTK_ACCESSIBLE (parent)->widget;
+          if (GTK_IS_MENU (widget))
+            {
+              if (GTK_WIDGET_MAPPED (widget))
+                gtk_menu_shell_cancel (GTK_MENU_SHELL (widget));
+
+              return;
+            }
+        }
+      parent = atk_object_get_parent (parent);
+    }
+}
+
 static gboolean
 idle_do_action (gpointer data)
 {
   GtkWidget *item;
   GtkWidget *item_parent;
   GailMenuItem *menu_item;
+  gboolean item_mapped;
 
   menu_item = GAIL_MENU_ITEM (data);
   menu_item->action_idle_handler = 0;
@@ -333,11 +358,14 @@ idle_do_action (gpointer data)
 
   item_parent = gtk_widget_get_parent (item);
   gtk_menu_shell_select_item (GTK_MENU_SHELL (item_parent), item);
+  item_mapped = GTK_WIDGET_MAPPED (item);
   /*
    * This is what is called when <Return> is pressed for a menu item
    */
   g_signal_emit_by_name (item_parent, "activate_current",  
                          /*force_hide*/ 1); 
+  if (!item_mapped)
+    ensure_menus_unposted (menu_item);
   return FALSE;
 }
 
