@@ -25,7 +25,7 @@
 static void      gail_notebook_page_class_init      (GailNotebookPageClass     *klass);
 
 static void                  gail_notebook_page_finalize       (GObject   *object);
-static gint                  gail_notebook_page_label_map_gtk  (GtkWidget *widget,
+static void                  gail_notebook_page_label_map_gtk  (GtkWidget *widget,
                                                                 gpointer  data);
 
 static G_CONST_RETURN gchar* gail_notebook_page_get_name       (AtkObject *accessible);
@@ -176,15 +176,33 @@ gail_notebook_page_class_init (GailNotebookPageClass *klass)
   gobject_class->finalize = gail_notebook_page_finalize;
 }
 
+static gint
+notify_child_added (gpointer data)
+{
+  GailNotebookPage *page;
+  AtkObject *atk_object, *atk_parent;
+
+  g_return_val_if_fail (GAIL_IS_NOTEBOOK_PAGE (data), FALSE);
+  page = GAIL_NOTEBOOK_PAGE (data);
+  atk_object = ATK_OBJECT (data);
+
+  atk_parent = gtk_widget_get_accessible (GTK_WIDGET (page->notebook));
+  atk_object_set_parent (atk_object, atk_parent);
+  g_signal_emit_by_name (atk_parent, "children_changed::add", page->index, atk_object, NULL);
+  
+  return FALSE;
+}
+
 AtkObject*
 gail_notebook_page_new (GtkNotebook *notebook, 
                         gint        pagenum)
 {
   GObject *object;
-  AtkObject *atk_object, *atk_child;
+  AtkObject *atk_object;
   GailNotebookPage *page;
   GtkWidget *child;
   GtkWidget *label;
+  GList *list;
   
   g_return_val_if_fail (GTK_IS_NOTEBOOK (notebook), NULL);
 
@@ -200,15 +218,15 @@ gail_notebook_page_new (GtkNotebook *notebook,
   page->notebook = notebook;
   g_object_add_weak_pointer (G_OBJECT (page->notebook), (gpointer *)&page->notebook);
   page->index = pagenum;
+  list = g_list_nth (notebook->children, pagenum);
+  page->page = list->data;
   page->textutil = NULL;
   
   atk_object = ATK_OBJECT (page);
   atk_object->role = ATK_ROLE_PAGE_TAB;
   atk_object->layer = ATK_LAYER_WIDGET;
 
-  atk_child = gtk_widget_get_accessible (child);
-  atk_object_set_parent (atk_child, atk_object);
-  
+  g_idle_add (notify_child_added, atk_object);
   /*
    * We get notified of changes to the label
    */
@@ -227,7 +245,7 @@ gail_notebook_page_new (GtkNotebook *notebook,
   return atk_object;
 }
 
-static gint
+static void
 gail_notebook_page_label_map_gtk (GtkWidget *widget,
                                   gpointer data)
 {
